@@ -1,10 +1,10 @@
 // parse a date in yyyy-mm-dd format
 function parse_date(date_string) {
-    if (!date_string) return new Date(1970,1,1);
+    if (!date_string) return new Date(Date.UTC(1970,1,1));
     // hat tip: http://stackoverflow.com/questions/2587345/javascript-date-parse    
     var parts = date_string.match(/(\d+)/g);
     // new Date(year, month [, date [, hours[, minutes[, seconds[, ms]]]]])
-    return new Date(parts[0], parts[1]-1, parts[2]); // months are 0-based
+    return new Date(Date.UTC(parts[0], parts[1]-1, parts[2])); // months are 0-based
 }
  
 function get_date(xform_doc) {
